docsgen

package
v1.4.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package docsgen plans documentation derived from a project inspection.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildPlan

func BuildPlan(prj *project.Project, force bool) (*plan.Plan, error)

BuildPlan generates managed Markdown files without replacing custom docs.

Types

This section is empty.

Jump to