Documentation
¶
Overview ¶
Package integrations handles `ginger add <integration>` by generating platform integration files and updating go.mod dependencies.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrIntegrationExists = errors.New("integration already exists")
ErrIntegrationExists is returned when the target integration file already exists.
Functions ¶
func NeedsPostApply ¶ added in v1.4.0
NeedsPostApply reports whether the plan created or replaced the integration implementation and therefore needs dependency installation.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.